"use client"

import { useState, useEffect } from "react"
import { useRouter } from "next/navigation"
import { X, BookOpen, CheckCircle } from "lucide-react"
import type { Exercise } from "@/types/course"
import { getExercisesByChapter } from "@/services/exercise-service"

type ExerciseModalProps = {
  isOpen: boolean
  onClose: () => void
  chapterId: string
  chapterTitle: string
}

export default function ExerciseModal({ isOpen, onClose, chapterId, chapterTitle }: ExerciseModalProps) {
  const router = useRouter()
  const [exercises, setExercises] = useState<Exercise[]>([])
  const [loading, setLoading] = useState(true)

  useEffect(() => {
    if (isOpen) {
      async function loadExercises() {
        try {
          const data = await getExercisesByChapter(chapterId)
          setExercises(data)
        } catch (error) {
          console.error("Erreur lors du chargement des exercices:", error)
        } finally {
          setLoading(false)
        }
      }

      loadExercises()
    }
  }, [isOpen, chapterId])

  if (!isOpen) return null

  const handleStartExercise = (exerciseId: string) => {
    router.push(`/exercices/${exerciseId}`)
    onClose()
  }

  return (
    <div className="fixed inset-0 bg-black bg-opacity-50 flex justify-center items-center z-50 p-4">
      <div className="bg-white rounded-lg shadow-xl max-w-3xl w-full max-h-[90vh] overflow-hidden">
        <div className="flex justify-between items-center p-6 border-b">
          <div>
            <h2 className="text-2xl font-bold">Liste des exercices</h2>
            <p className="text-gray-600">Liste des exercices du chapitre: {chapterTitle}</p>
          </div>
          <button onClick={onClose} className="text-gray-500 hover:text-gray-700">
            <X className="h-6 w-6" />
          </button>
        </div>

        <div className="p-6 overflow-y-auto max-h-[calc(90vh-120px)]">
          {loading ? (
            <div className="flex justify-center items-center h-40">
              <div className="animate-spin rounded-full h-10 w-10 border-t-2 border-b-2 border-blue-500"></div>
            </div>
          ) : exercises.length === 0 ? (
            <div className="text-center py-8">
              <p className="text-gray-600">Aucun exercice disponible pour ce chapitre.</p>
            </div>
          ) : (
            <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
              {exercises.map((exercise) => (
                <div key={exercise.id} className="border rounded-lg p-4 hover:bg-gray-50 transition-colors">
                  <div className="flex items-start mb-3">
                    <BookOpen className="h-5 w-5 text-blue-500 mr-2 mt-1" />
                    <div>
                      <h3 className="font-semibold">{exercise.title}</h3>
                      <p className="text-sm text-gray-600">{exercise.description}</p>
                    </div>
                  </div>

                  <div className="flex items-center justify-between text-xs text-gray-500 mb-3">
                    <div className="flex items-center">
                      <CheckCircle className="h-3 w-3 mr-1 text-green-500" />
                      <span>{exercise.questions.length} questions</span>
                    </div>
                    <span>Durée estimée: {exercise.questions.length * 30} secondes</span>
                  </div>

                  <button
                    onClick={() => handleStartExercise(exercise.id)}
                    className="w-full bg-green-600 hover:bg-green-700 text-white py-2 px-4 rounded text-sm"
                  >
                    Commencer l'exercice
                  </button>
                </div>
              ))}
            </div>
          )}
        </div>

        <div className="p-6 border-t bg-gray-50">
          <button onClick={onClose} className="bg-gray-200 hover:bg-gray-300 text-gray-800 py-2 px-6 rounded">
            Fermer
          </button>
        </div>
      </div>
    </div>
  )
}
